/**
 * A `<details>` element packaged nicely to animate like a disclosure.
 *
 * @customElement
 * @tagname light-disclosure
 *
 * @slot default - The code to use for highlighting
 */
export default class LightDisclosure extends BaseElement {
    /**
     * @override
     */
    static override styles: import("lit").CSSResult[];
    /**
     * @override
     */
    static override properties: {
        summary: {};
        open: {
            type: BooleanConstructor;
        };
    };
    /**
     * @type {string}
     */
    summary: string;
    /**
     * @type {boolean}
     */
    open: boolean;
    /**
     * @internal
     * This is used because Safari has strange timing on the "toggle" event. If we don't use this,
     *   our initial opening of the disclosure gets clipped and is like a normal `<details>`
     */
    _openOnToggle: boolean;
    /**
     * @override
     * @param {import("lit").PropertyValues<this>} changedProperties
     */
    override willUpdate(changedProperties: import("lit").PropertyValues<this>): void;
    /**
     * @override
     */
    override click(): void;
    /**
     * @override
     * @param {FocusOptions} [options]
     */
    override focus(options?: FocusOptions | undefined): void;
    /**
     * @override
     */
    override render(): import("lit").TemplateResult<1>;
    get details(): HTMLDetailsElement | null | undefined;
    /**
     * @param {TransitionEvent} e
     */
    handleTransitionEnd(e: TransitionEvent): void;
    /**
     * Toggle fires after the attribute is set / unset, so its useless for expanded. But useful for when users search a page with "ctrl+f"
     * @param {Event} _e
     */
    handleToggle(_e: Event): void;
    /**
     * @param {Event} e
     */
    handleSummaryClick(e: Event): false | undefined;
}
import { BaseElement } from "../../../internal/base-element.js";
